// {{{ copyright

/********************************************************************
 *
 * $Id: DialogCommandException.java,v 1.5 2000/07/04 13:39:48 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.command;

import java.awt.Dialog;

/**
 * When a DialogCommandException is thrown during the exection of a {@link
 * Command Command} that has been assigned through a {@link CommandDistributor
 * CommandDistributor}, it will be caught and the Dialog contained in it will
 * be displayed.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.5 $
 */
public class DialogCommandException extends CommandException
{
    // {{{ variables

    /**
     * The dialog of the DialogCommandException.
     */
    private Dialog dialog;

    // }}}

    // {{{ constructor

    /**
     * Create a new DialogCommandException.
     *
     * @param   message A message detailing the reason for the exception.
     * @param   dialog  The dialog to display when the exception is caught.
     */
    public DialogCommandException (String message, Dialog dialog)
    {
        super (message);
        this.dialog = dialog;
    }

    // }}}

    // {{{ getDialog

    /**
     * Get the Dialog of the DialogCommandException.
     *
     * @return  The dialog of the DialogCommandException.
     */
    public final Dialog getDialog()
    {
        return dialog;
    }

    // }}}
}
