// {{{ copyright

/********************************************************************
 *
 * $Id: MessageCommandException.java,v 1.4 2000/06/06 17:00:02 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.command;

// {{{ imports

import java.awt.Component;

import java.util.ResourceBundle;
import java.util.MissingResourceException;

// }}}

/**
 * When a MessageCommandException is thrown during the exection of a {@link
 * Command Command} that has been assigned through a {@link CommandDistributor
 * CommandDistributor}, it will be caught and a Dialog for the contained
 * message will be displayed through {@link de.qfs.lib.gui.Message#showMessage
 * Message.showMessage}.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.4 $
 */
public class MessageCommandException extends CommandException
{
    // {{{ variables

    /**
     * The parent of the MessageCommandException.
     */
    private Component parent;

    /**
     * The messageResource of the MessageCommandException.
     */
    private String messageResource;

    /**
     * The messageParameters of the MessageCommandException.
     */
    private Object[] messageParameters;

    // }}}

    // {{{ constructors

    /**
     * Create a new MessageCommandException.
     *
     * @param   message A message detailing the reason for the exception.
     * @param   parent  The parent Component for the dialog to display.
     * @param   messageResource The resource basename for the message dialog.
     *
     * @see     de.qfs.lib.gui.Message#showMessage(Component,String,Object[])
     */
    public MessageCommandException (String message,
                                    Component parent,
                                    String messageResource)
    {
        this (message, parent, messageResource, null);
    }

    /**
     * Create a new MessageCommandException.
     *
     * @param   message A message detailing the reason for the exception.
     * @param   parent  The parent Component for the dialog to display.
     * @param   messageResource The resource basename for the message dialog.
     * @param   parameters The parameters for the message.
     *
     * @see     de.qfs.lib.gui.Message#showMessage(Component,String,Object[])
     */
    public MessageCommandException (String message,
                                    Component parent,
                                    String messageResource,
                                    Object[] parameters)
    {
        super (message);
        this.parent = parent;
        this.messageResource = messageResource;
        this.messageParameters = parameters;
    }

    // }}}

    // {{{ getParent

    /**
     * Get the parent of the MessageCommandException.
     *
     * @return  The parent of the MessageCommandException.
     */
    public final Component getParent()
    {
        return parent;
    }

    // }}}
    // {{{ getMessageResource

    /**
     * Get the messageResource of the MessageCommandException.
     *
     * @return  The messageResource of the MessageCommandException.
     */
    public final String getMessageResource()
    {
        return messageResource;
    }

    // }}}
    // {{{ getMessageParameters

    /**
     * Get the messageParameters of the MessageCommandException.
     *
     * @return  The messageParameters of the MessageCommandException.
     */
    public final Object[] getMessageParameters()
    {
        return messageParameters;
    }

    // }}}
}
