// {{{ copyright

/********************************************************************
 *
 * $Id: UnhandledCommandException.java,v 1.5 2000/10/03 14:39:05 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.command;

/**
 * This exception is thrown by {@link CommandDistributor#assignCommandSilently
 * CommandDistributor.assignCommandSilently}, when a {@link Command Command}
 * has been passed through all possible {@link CommandHandler CommandHandlers}
 * and is still not handled.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.5 $
 */
public class UnhandledCommandException extends CommandException
{
    // {{{ variables

    /**
     * The command of the UnhandledCommandException.
     */
    private Command command;

    // }}}

    // {{{ constructor

    /**
     * Create a new UnhandledCommandException.
     *
     * @param   command The Command that could not be handled.
     */
    public UnhandledCommandException (Command command)
    {
        super ("Unhandled command: " + command);
        this.command = command;
    }

    // }}}

    // {{{ getCommand

    /**
     * Get the command of the UnhandledCommandException.
     *
     * @return  The command of the UnhandledCommandException.
     */
    public final Command getCommand()
    {
        return command;
    }

    // }}}
}
