// {{{ copyright

/********************************************************************
 *
 * $Id: LimitedDocument.java,v 1.6 2000/06/06 17:00:02 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.gui;

// {{{ imports

import javax.swing.text.Document;
import javax.swing.text.PlainDocument;
import javax.swing.text.AttributeSet;
import javax.swing.text.BadLocationException;

// }}}

/**
 * An extension of PlainDocument that limits the number of characters the
 * Document may hold.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.6 $
 */
public class LimitedDocument extends PlainDocument
{
    // {{{ variables

    /**
     * The number of characters allowed.
     */
    private int limit;

    // }}}

    // {{{ LimitedDocument

    /**
     * Create a new LimitedDocument.
     */
    public LimitedDocument ()
    {
    }

    // }}}

    // {{{ setLimit

    /**
     * Set the limit for the number of characters.
     *
     * @param   limit   The limit to set.
     */
    public void setLimit(int limit)
    {
        this.limit = limit;
    }

    // }}}
    // {{{ insertString

    /**
     * Insert a string into the document. Only adds as much of string as will
     * fit without exceeding the document's size limit.
     *
     * @param   offs    The offset to insert at.
     * @param   str     The string to insert.
     * @param   a       The string's attributes.
     *
     * @throws  BadLocationException    If the offset is illegal for the
     *                                  document.
     */
    public void insertString(int offs, String str, AttributeSet a)
         throws BadLocationException
    {
        if (str == null) {
            return;
        }

        int size = getEndPosition().getOffset() - 1;
        if (size < limit) {
            if (size + str.length() > limit) {
                str = str.substring(0, limit - size);
            }
            super.insertString(offs, str, a);
        }
    }

    // }}}
}
