// {{{ copyright

/********************************************************************
 *
 * $Id: LimitedTextArea.java,v 1.6 2000/06/06 17:00:03 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.gui;

// {{{ imports

import javax.swing.JTextArea;
import javax.swing.text.Document;

// }}}

/**
 * LimitedTextArea extends JTextArea to restrict the number of characters
 * that may be entered.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.6 $
 */
public class LimitedTextArea extends JTextArea
{
    // {{{ variables

    /**
     * The field's document.
     */
    private LimitedDocument ld;

    // }}}

    // {{{ constructors

    /**
     * Create a new LimitedTextArea.
     *
     * @param   limit   The maximum number of characters allowed.
     */
    public LimitedTextArea (int limit)
    {
        init(limit);
    }

    /**
     * Create a new LimitedTextArea.
     *
     * @param   text    Text to initialize the area with.
     * @param   limit   The maximum number of characters allowed.
     */
    public LimitedTextArea (String text, int limit)
    {
        super (text);
        init(limit);
    }

    /**
     * Create a new LimitedTextArea.
     *
     * @param   rows    Initial number of columns
     * @param   columns Initial number of columns
     * @param   limit   The maximum number of characters allowed.
     */
    public LimitedTextArea (int rows, int columns, int limit)
    {
        super(rows, columns);
        init(limit);
    }

    /**
     * Create a new LimitedTextArea.
     *
     * @param   text    Text to initialize the area with.
     * @param   rows    Initial number of columns
     * @param   columns Initial number of columns
     * @param   limit   The maximum number of characters allowed.
     */
    public LimitedTextArea (String text, int rows, int columns, int limit)
    {
        super (text, rows, columns);
        init(limit);
    }

    // }}}

    // {{{ createDefaultModel

    /**
     * Create the default document model for the field.
     *
     * @return  The Document created.
     */
    protected Document createDefaultModel()
    {
        if (ld == null) {
            ld = new LimitedDocument();
        }
        return ld;
    }

    // }}}

    // {{{ init

    /**
     * Initialize the document.
     *
     * @param   limit   The limit for the size of the field.
     */
    private void init (int limit)
    {
        if (ld == null) {
            ld = new LimitedDocument();
        }
        ld.setLimit(limit);
    }

    // }}}
}

