// {{{ copyright

/********************************************************************
 *
 * $Id: TableModelFilter.java,v 1.5 2000/06/06 17:00:03 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.gui;

import javax.swing.table.TableModel;

/**
 * Interface for filters used by {@link FilteredAndSortedTableModel
 * FilteredAndSortedTableModel}. The filter method will be called with the
 * original {@link javax.swing.table.TableModel TableModel} an a row index
 * for this model.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.5 $
 */

public interface TableModelFilter
{
    /**
     * Decide, whether a row should be displayed or filtered.
     *
     * @param model     The original TableModel.
     * @param row       The row index.
     *
     * @return True, if the row should be displayed.
     */
    public boolean filter (TableModel model, int row);

    /**
     * Add a TableModelFilterListener to the TableModelFilter.
     *
     * @param   listener        The TableModelFilterListener to add.
     */
    public void addTableModelFilterListener(TableModelFilterListener listener);

    /**
     * Remove a TableModelFilterListener from the TableModelFilter.
     *
     * @param   listener        The TableModelFilterListener to remove.
     */
    public void removeTableModelFilterListener
        (TableModelFilterListener listener);

}
