// {{{ copyright

/********************************************************************
 *
 * $Id: TableModelSorterEvent.java,v 1.7 2000/06/06 16:41:26 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.gui;

// {{{ imports

import java.util.EventObject;

import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

// }}}

/**
 * This event contains the details about a change in the sort order of
 * a {@link TableModelSorter TableModelSorter}.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.7 $
 */
public class TableModelSorterEvent
    extends EventObject
{
    // {{{ variables

    /**
     * The Logger used for logging.
     */
    private static Logger logger = new Logger (TableModelSorterEvent.class);

    /**
     * The new sort column of the TableModelSorter.
     */
    private int column;

    /**
     * Whether the sort order is ascending or descending.
     */
    private boolean ascending;

    // }}}

    // {{{ constructor

    /**
     * Create a new TableModelSorterEvent.
     *
     * @param   source    The source of the event.
     * @param   column    The new sort column of the TableModelSorter.
     * @param   ascending Whether the sort order is ascending.
     */
    public TableModelSorterEvent(Object source, int column, boolean ascending)
    {
        super(source);
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "TableModelSorterEvent(int,boolean)",
                       logger.level < Log.MTDDETAIL ? "" :
                       "column: " + column + ", " +
                       "ascending: " + ascending);
        }
        this.column = column;
        this.ascending = ascending;
    }

    // }}}

    // {{{ getColumn

    /**
     * Get the new sort coulmn of the TableModelSorter.
     */
    public final int getColumn()
    {
        return column;
    }

    // }}}
    // {{{ isAscending

    /**
     * Query whether the sort order is ascending.
     */
    public final boolean isAscending()
    {
        return ascending;
    }

    // }}}
}
