// {{{ copyright

/********************************************************************
 *
 * $Id: NestedOption.java,v 1.6 2000/06/06 16:41:27 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.option;

// {{{ imports

import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

// }}}

/**
 * A NestedOption's value is an {@link OptionSet OptionSet}. This makes is
 * possible to build tree hierarchies of {@link Option Options} and
 * OptionSets. <p>
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.6 $
 */
public class NestedOption extends Option
{
    // {{{ variables

    /**
     * The UID used for serialization.
     */
    static final long serialVersionUID = 2793219611241463721L;

    /**
     * The Logger used for logging.
     */
    private static Logger logger = new Logger (NestedOption.class);

    // }}}

    // {{{ constructors

    /**
     * Create a new NestedOption.
     */
    public NestedOption ()
    {
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "NestedOption()", "");
        }
    }

    /**
     * Create a new NestedOption with a name and a value.
     *
     * @param   name    The name to use.
     * @param   value   The value to use.
     */
    public NestedOption (String name, OptionSet value)
    {
        super (name, value);
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "NestedOption(String,Object)",
                       logger.level < Log.MTDDETAIL ? "" :
                       "name: " + name + ", " +
                       "value: " + value);
        }
    }

    // }}}

    // {{{ equals

    /**
     * Two NestedOptions are considered equal if their names and values
     * are equal.
     *
     * @param   object  The object to compare to.
     *
     * @return  True if objects are equal
     */
    public boolean equals(Object object)
    {
        return (object instanceof NestedOption) && super.equals(object);
    }

    // }}}
}
