// {{{ copyright

/********************************************************************
 *
 * $Id: StringOption.java,v 1.8 2000/06/06 16:41:27 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.option;

// {{{ imports

import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

// }}}

/**
 * A StringOption's value is of class String.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.8 $
 */
public class StringOption
    extends Option
    implements ConfigurableOption
{
    // {{{ variables

    /**
     * The UID used for serialization.
     */
    static final long serialVersionUID = -2858370096152160671L;

    /**
     * The Logger used for logging.
     */
    private final static Logger logger = new Logger (StringOption.class);

    // }}}

    // {{{ constructors

    /**
     * Create a new StringOption.
     */
    public StringOption()
    {
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "StringOption()", "");
        }
    }

    /**
     * Create a new StringOption with a name and a value.
     *
     * @param   name    The name to use.
     * @param   value   The value to use.
     */
    public StringOption(String name, String value)
    {
        super (name, value);
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "StringOption(String,String)",
                       logger.level < Log.MTDDETAIL ? "" :
                       "name: " + name + ", " +
                       "value: " + value);
        }
    }

    /**
     * Create a new StringOption with a name and a value and the nullOK flag.
     *
     * @param   name    The name to use.
     * @param   value   The value to use.
     * @param   nullOK  The nullOK flag to use.
     */
    public StringOption(String name, String value, boolean nullOK)
    {
        super (name, value, nullOK);
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "StringOption(String,String,boolean)",
                       logger.level < Log.MTDDETAIL ? "" :
                       "name: " + name + ", " +
                       "value: " + value + ", " +
                       "nullOK: " + nullOK);
        }
    }

    // }}}

    // {{{ equals

    /**
     * Two StringOptions are considered equal if their names and values
     * are equal.
     *
     * @param   object  The object to compare to.
     *
     * @return  True if objects are equal
     */
    public boolean equals(Object object)
    {
        return (object instanceof StringOption) && super.equals(object);
    }

    // }}}

    //----------------------------------------------------------------------
    // the ConfigurableOption interface
    //----------------------------------------------------------------------
    // {{{ getConfigurableValue

    /**
     * Get the Option's value as a String.
     *
     * @return  The Option's value as a String.
     */
    public String getConfigurableValue()
    {
        String ret = (String) getValue();
        return ret == null ? "" : ret;
    }

    // }}}
    // {{{ setConfigurableValue

    /**
     * Set the Option's value from a String.
     *
     * @param   val     The value to set.
     */
    public void setConfigurableValue(String val)
    {
        setValue(val.equals("") ? null : val);
    }

    // }}}
}
