// {{{ copyright

/********************************************************************
 *
 * $Id: OpenTransactionException.java,v 1.5 2000/06/14 16:51:54 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.transaction;

// {{{ imports

import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

// }}}

/**
 * An OpenTransactionException is thrown, when a {@link Transaction
 * Transaction} is created for a Thread that already has an open
 * Transaction. <p>
 *
 * Since this Exception will not be thrown during typical program flow,
 * it is derived from RuntimeException.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.5 $
 * @since       0.97.0
 */
public class OpenTransactionException extends RuntimeException
{
    // {{{ variables

    /**
     * The Logger used for logging.
     */
    private final static Logger logger =
        new Logger (OpenTransactionException.class);

    // }}}

    // {{{ constructor

    /**
     * Create a new OpenTransactionException.
     *
     * @param   detail  A message stating the reason for the Exception.
     */
    public OpenTransactionException (String detail)
    {
        super (detail);
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "OpenTransactionException(String)",
                       logger.level < Log.MTDDETAIL ? "" :
                       "detail: " + detail);
        }
    }

    // }}}
}
