// {{{ copyright

/********************************************************************
 *
 * $Id: MutableTraversal.java,v 1.3 2001/04/21 19:55:02 gs Exp $
 *
 * Copyright (C) 2000 Gregor Schmid, Quality First Software
 * All rights reserved
 *
 *******************************************************************/

// }}}

package de.qfs.lib.tree;

// {{{ imports

import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

// }}}

/**
 * Extension of the Traversal interface that enables modification of the
 * tree during traversal.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.3 $
 * @since       0.98.1
 */
public interface MutableTraversal
    extends Traversal
{
    // {{{ removeNode

    /**
     * Remove the current node of the traversal.
     *
     * @return  True if the node could be removed, false otherwise.
     */
    public boolean removeNode();

    // }}}
    // {{{ nodeRemoved

    /**
     * Notify the traversal that the currently visited node has been removed.
     */
    public void nodeRemoved();

    // }}}
    // {{{ insertNodeBefore

    /**
     * Insert a node before the current node of the traversal.
     *
     * @param   node    The node to insert.
     *
     * @return  True if the node could be inserted, false if not.
     */
    public boolean insertNodeBefore(Object node);

    // }}}
    // {{{ nodeInsertedBefore

    /**
     * Notify the traversal that a node has been inserted before the currently
     * visited node.
     *
     * @param node The inserted node which will become the node returned by
     * {@link #getPreviousSibling getPreviousSibling}.
     */
    public void nodeInsertedBefore(Object node);

    // }}}
    // {{{ insertNodeAfter

    /**
     * Insert a node after the current node of the traversal.
     *
     * @param   node    The node to insert.
     *
     * @return  True if the node could be inserted, false if not.
     */
    public boolean insertNodeAfter(Object node);

    // }}}
    // {{{ nodeInsertedAfter

    /**
     * Notify the traversal that a node has been inserted after the currently
     * visited node.
     *
     * @param node The inserted node.
     */
    public void nodeInsertedAfter(Object node);

    // }}}
}
