// {{{ copyright

/********************************************************************
 *
 * $Id: TraversalCallback.java,v 1.2 2001/04/06 15:03:52 gs Exp $
 *
 * Copyright (C) 2000 Gregor Schmid, Quality First Software
 * All rights reserved
 *
 *******************************************************************/

// }}}

package de.qfs.lib.tree;

// {{{ imports

import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

// }}}

/**
 * This interface must be implemented when traversing a tree with {@link
 * TreeUtil#traverse TreeUtil.traverse} or {@link TreeUtil#traverseFrom
 * TreeUtil.traverseFrom}.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.2 $
 * @since       0.98.1
 */
public interface TraversalCallback
{
    // {{{ nodeEntered

    /**
     * Notify the Callback that a node has been entered during traversal.
     *
     * @param node  The node just entered.
     *
     * @return True if the children of the node should be traversed as
     *         well, false to ignore them.
     *
     * @throws ReturnFromTraversalException If the traversal should be
     * terminated prematurely.
     */
    public boolean nodeEntered(Traversal traversal)
        throws ReturnFromTraversalException;

    // }}}
    // {{{ nodeExited

    /**
     * Notify the Callback that a node has been exited during traversal.
     *
     * @param node  The node just exited.
     *
     * @throws ReturnFromTraversalException If the traversal should be
     * terminated prematurely.
     */
    public void nodeExited(Traversal traversal)
        throws ReturnFromTraversalException;

    // }}}

}
