// {{{ copyright

/********************************************************************
 *
 * $Id: ClassEntry.java,v 1.4 2000/06/06 17:00:04 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.util;

import java.io.File;

import java.util.zip.ZipFile;

/**
 * Simple holder for cached class information.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.4 $
 */
class ClassEntry
{
    // {{{ variables


    /**
     * The Class.
     */
    public Class clazz;

    /**
     * The file containing the classes data.
     */
    public File file;

    /**
     * The ZipFile containing the class or null, if it comes from an unzipped
     * .class file.
     */
    public ZipFile zip;

    /**
     * The modification time of the class file when the class was created.
     */
    public long timestamp;

    // }}}

    // {{{ constructors

    /**
     * Create a new ClassEntry for a standard .class file.
     *
     * @param   clazz   The class.
     * @param   source  The class file.
     */
    public ClassEntry (Class clazz, File source)
    {
        this.clazz = clazz;
        file = source;
        timestamp = source.lastModified();
    }

    /**
     * Create a new ClassEntry for a class from a ZipFile.
     *
     * @param   clazz   The class.
     * @param   source  The ZipFile containing the class.
     */
    public ClassEntry (Class clazz, ZipFile source)
    {
        this.clazz = clazz;
        zip = source;
        file = new File (source.getName());
        timestamp = file.lastModified();
    }

    // }}}
}
