// {{{ copyright

/********************************************************************
 *
 * $Id: StreamInput.java,v 1.6 2000/06/06 17:00:04 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.util;

// {{{ imports

import java.io.InputStream;
import java.io.IOException;

import java.util.Vector;

import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

// }}}

/**
 * Helper to read all bytes from a stream into a byte array.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.6 $
 */
public class StreamInput
{
    // {{{ variables

    /**
     * The Logger used for logging.
     */
    private static Logger logger = new Logger (StreamInput.class);

    /**
     * Number of bytes to read in one go.
     */
    private static final int BLOCKSIZE = 4096;

    // }}}

    // {{{ read

    /**
     * Read all bytes from a stream into a byte array. Should only be used
     * when the input stream is known to be limited to a reasonable size.
     *
     * @param   in      The input stream.
     *
     * @return  The byte array.
     *
     * @throws  IOException     If an I/O error occurs.
     */
    public static byte[] read(InputStream in)
         throws IOException
    {
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "read(InputStream)",
                       logger.level < Log.MTDDETAIL ? "" :
                       "in: " + in);
        }

        Vector bufs = new Vector ();
        Vector sizes = new Vector ();
        int size = 0;
        while (true) {
            byte[] tmp = new byte [BLOCKSIZE];
            int ret = in.read(tmp);
            if (ret < 0) {
                break;
            }
            if (ret > 0) {
                size += ret;
                bufs.addElement(tmp);
                sizes.addElement(new Integer (ret));
            }
        }

        byte[] buf = new byte[size];
        int pos = 0;
        for (int i = 0; i < bufs.size(); i++) {
            byte[] tmp = (byte[]) bufs.elementAt(i);
            int len = ((Integer)sizes.elementAt(i)).intValue();
            System.arraycopy(tmp, 0, buf, pos, len);
            pos += len;
        }
        return buf;
    }

    // }}}
}

