// {{{ copyright

/********************************************************************
 *
 * $Id: UnexpectedParameterException.java,v 1.2 2000/07/10 13:29:57 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 2000 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.util;

/**
 * This exception is thrown by {@link de.qfs.lib.util.ArgsParser#parse
 * ArgsParser.parse} when it encouters an option that may not have a
 * parameter, but one was given on the command line or in the options file.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.2 $
 */
public class UnexpectedParameterException
    extends MalformedArgumentListException
{
    // {{{ variables

    /**
     * The parameter that caused the exception.
     */
    private String parameter;

    // }}}

    // {{{ constructor

    /**
     * Create a new UnexpectedParameterException.
     *
     * @param   message A message explaining the reason for the exception.
     * @param   option  The option that caused the exception.
     * @param   parameter The parameter that caused the exception.
     */
    public UnexpectedParameterException(String message, String option,
                                        String parameter)
    {
        super(message, option);
        this.parameter = parameter;
    }

    // }}}

    // {{{ getParameter

    /**
     * Get the parameter that caused the exception.
     *
     * @return  The parameter that caused the exception.
     */
    public String getParameter()
    {
        return parameter;
    }

    // }}}
}
